@@ -676,42 +676,54 @@ nautil_check(int wordsize, int m, int n, int version)
 {
 	if (wordsize != WORDSIZE)
 	{
+#ifdef MSG
 	    fprintf(ERRFILE,"Error: WORDSIZE mismatch in nautil.c\n");
-	    exit(1);
+#endif
+	    EXIT(1);
 	}
 
 #if MAXN
 	if (m > MAXM)
 	{
+#ifdef MSG
 	    fprintf(ERRFILE,"Error: MAXM inadequate in nautil.c\n");
-	    exit(1);
+#endif
+	    EXIT(1);
 	}
 
 	if (n > MAXN)
 	{
+#ifdef MSG
 	    fprintf(ERRFILE,"Error: MAXN inadequate in nautil.c\n");
-	    exit(1);
+#endif
+	    EXIT(1);
 	}
 #endif
 
 #ifdef BIGNAUTY
 	if ((version & 1) == 0)
-        {   
+        { 
+#ifdef MSG  
             fprintf(ERRFILE,"Error: BIGNAUTY mismatch in nautil.c\n");
-            exit(1);
+#endif
+            EXIT(1);
         }
 #else
         if ((version & 1) == 1)
-        {   
+        {  
+#ifdef MSG 
             fprintf(ERRFILE,"Error: BIGNAUTY mismatch in nautil.c\n");
-            exit(1);
+#endif
+            EXIT(1);
         }
 #endif
 
         if (version < NAUTYREQUIRED)
         {
+#ifdef MSG
             fprintf(ERRFILE,"Error: nautil.c version mismatch\n");
-            exit(1);
+#endif
+            EXIT(1);
         }
 }
 
@@ -724,8 +736,10 @@ nautil_check(int wordsize, int m, int n, int version)
 void
 alloc_error(char *s)
 {
+#ifdef MSG
         fprintf(ERRFILE,"Dynamic allocation failed: %s\n",s);
-        exit(2);
+#endif
+        EXIT(2);
 }
 
 /*****************************************************************************
